==> haskell-microlens-mtl-0.1.11.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-mtl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-mtl
version: 0.1.11.1
id: microlens-mtl-0.1.11.1-F46NcsxtAjc5NhO4kHlQKE
key: microlens-mtl-0.1.11.1-F46NcsxtAjc5NhO4kHlQKE
license: BSD-3-Clause
maintainer: Artyom <yom@artyom.me>
author: Edward Kmett, Artyom
homepage: http://github.com/aelve/microlens
synopsis: microlens support for Reader/Writer/State from mtl
description:
    This package contains functions (like '\''view'\'' or '\''+='\'') which work on '\''MonadReader'\'', '\''MonadWriter'\'', and '\''MonadState'\'' from the mtl package.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/aelve/microlens#readme on Github>.
category: Data, Lenses
abi: 454ef19a1139cc9f6583f42a042d5c24
exposed: True
exposed-modules:
    Lens.Micro.Mtl Lens.Micro.Mtl.Internal
import-dirs: /usr/lib/ghc-8.6.4/site-local/microlens-mtl-0.1.11.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/microlens-mtl-0.1.11.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/microlens-mtl-0.1.11.1
hs-libraries: HSmicrolens-mtl-0.1.11.1-F46NcsxtAjc5NhO4kHlQKE
depends:
    base-4.12.0.0 microlens-0.4.10-LVgmazyXGvNKvoQElrYSfS mtl-2.2.2
    transformers-0.5.6.2
    transformers-compat-0.6.2-IT1pgM4Lod5B9rerVXsOk7
haddock-interfaces: /usr/share/doc/haskell-microlens-mtl/html/microlens-mtl.haddock
haddock-html: /usr/share/doc/haskell-microlens-mtl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-mtl-0.1.11.1-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-mtl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-mtl
version: 0.1.11.1
id: microlens-mtl-0.1.11.1-6U2K56DzIyY4kKXnpNGylh
key: microlens-mtl-0.1.11.1-6U2K56DzIyY4kKXnpNGylh
license: BSD-3-Clause
maintainer: Artyom <yom@artyom.me>
author: Edward Kmett, Artyom
homepage: http://github.com/aelve/microlens
synopsis: microlens support for Reader/Writer/State from mtl
description:
    This package contains functions (like '\''view'\'' or '\''+='\'') which work on '\''MonadReader'\'', '\''MonadWriter'\'', and '\''MonadState'\'' from the mtl package.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/aelve/microlens#readme on Github>.
category: Data, Lenses
abi: 6f7294bd1fd935f8fb8acb6714df0e04
exposed: True
exposed-modules:
    Lens.Micro.Mtl Lens.Micro.Mtl.Internal
import-dirs: /usr/lib/ghc-8.6.4/site-local/microlens-mtl-0.1.11.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/microlens-mtl-0.1.11.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/microlens-mtl-0.1.11.1
hs-libraries: HSmicrolens-mtl-0.1.11.1-6U2K56DzIyY4kKXnpNGylh
depends:
    base-4.12.0.0 microlens-0.4.10-LVgmazyXGvNKvoQElrYSfS mtl-2.2.2
    transformers-0.5.6.2
    transformers-compat-0.6.3-1NtilqZTjCV2jyq6SVF8I5
haddock-interfaces: /usr/share/doc/haskell-microlens-mtl/html/microlens-mtl.haddock
haddock-html: /usr/share/doc/haskell-microlens-mtl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
